@@ -112,6 +112,7 @@ class SimliClient:
         enable_logging: bool = True,
         retry_count: int = 30,
         retry_timeout: float = 15.0,
+        enableSFU: bool = True,
     ):
         """
         :param config: SimliConfig object containing the API Key and Face ID and other optional parameters for the Simli API refer to https://docs.simli.com for more information
@@ -138,6 +139,7 @@ class SimliClient:
         self.starting = False
         self.speak_event: Optional[Awaitable] = None
         self.silent_event: Optional[Awaitable] = None
+        self.enableSFU = enableSFU
 
     async def Initialize(
         self,
@@ -210,7 +212,7 @@ class SimliClient:
             jsonOffer = self.pc.localDescription.__dict__
             self.wsConnection: websockets.asyncio.client.ClientConnection = (
                 websockets.asyncio.client.connect(
-                    f"{self.simliWSURL}/StartWebRTCSession"
+                    f"{self.simliWSURL}/StartWebRTCSession?enableSFU={self.enableSFU}"
                 )
             )
             self.wsConnection = await self.wsConnection.__aenter__()
@@ -223,17 +225,14 @@ class SimliClient:
 
             await self.wsConnection.send(self.session_token)
             await self.pc.setRemoteDescription(answer)
-            message = await self.wsConnection.recv()
-            if self.enable_logging:
-                print(message)  # ACK
             ready = await self.wsConnection.recv()  # START MESSAGE
             while ready != "START":
                 if self.enable_logging:
                     print(ready)
                 ready = await self.wsConnection.recv()  # START MESSAGE
             self.ready.set()
-            await self.sendSilence(1)
             self.receiverTask = asyncio.create_task(self.handleMessages())
+            await self.sendSilence(1)
 
             if self.latencyInterval > 0:
                 self.pingTask = asyncio.create_task(self.ping(self.latencyInterval))
@@ -294,6 +293,9 @@ class SimliClient:
             elif message == "SPEAK" and self.speak_event is not None:
                 await self.speak_event()
 
+            elif message == "MISSING_SESSION_TOKEN":
+                await self.wsConnection.send(self.session_token)
+
             elif message != "ACK" and self.enable_logging:
                 print(message)
 
